# Generated by Django 2.1.7 on 2019-02-21 09:34

from django.conf import settings
from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0007_auto_20190216_2323'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user_permission',
            name='user',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='user_permission',
            name='widget',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='isc_common.Widgets_trees'),
        ),
        migrations.AlterField(
            model_name='usergroup_permission',
            name='usergroup',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='isc_common.UserGroup'),
        ),
        migrations.AlterField(
            model_name='usergroup_permission',
            name='widget',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='isc_common.Widgets_trees'),
        ),
    ]
